package com.cloud.kicc.common.data.entity;

import com.cloud.kicc.common.core.enums.CasSystemEnum;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.User;

import java.time.LocalDateTime;
import java.util.Collection;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 *<p>
 * CAS统一认证用户数据
 *</p>
 *
 * @Author: wangxiang4
 * @Since: 2023/8/16
 */
@Setter
@Getter
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
public class CasUser extends User {

	private static final long serialVersionUID = 1L;

	/** 用户ID */
	private String id;

	/** 昵称 */
	private String nickName;

	/** 邮箱 */
	private String email;

	/** 手机号 */
	private String phone;

	/** 性别 */
	private String sex;

	/** 头像地址 */
	private String avatar;

	/** 最后登陆ip */
	private String loginIp;

	/** 最后登陆时间 */
	private LocalDateTime loginTime;

	/** 状态 */
	private String ssoStatus;

	/** 创建ID */
	private String ssoCreateById;

	/** 创建人 */
	private String ssoCreateByName;

	/** 创建时间 */
	private LocalDateTime ssoCreateTime;

	/** 更新ID */
	private String ssoUpdateById;

	/** 更新人 */
	private String ssoUpdateByName;

	/** 更新时间 */
	private LocalDateTime ssoUpdateTime;

	/** 备注 */
	private String remarks;

	/** 角色ID */
	private String roleId;

	/** 多租户ID */
	private String tenantId;

	/** sso扩展信息 */
	private Map<CasSystemEnum, String> exPrincipals = new ConcurrentHashMap<>(3);


	public CasUser(String username, String password, Collection<? extends GrantedAuthority> authorities) {
		super(username, password, authorities);
	}

	public CasUser(String username, String password, boolean enabled, boolean accountNonExpired, boolean credentialsNonExpired, boolean accountNonLocked, Collection<? extends GrantedAuthority> authorities) {
		super(username, password, enabled, accountNonExpired, credentialsNonExpired, accountNonLocked, authorities);
	}

	public CasUser(String username,
				   String password,
				   boolean enabled,
				   boolean accountNonExpired,
				   boolean credentialsNonExpired,
				   boolean accountNonLocked,
				   Collection<? extends GrantedAuthority> authorities,
				   String id,
				   String nickName,
				   String email,
				   String phone,
				   String sex,
				   String avatar,
				   String loginIp,
				   LocalDateTime loginTime,
				   String ssoStatus,
				   String ssoCreateById,
				   String ssoCreateByName,
				   LocalDateTime ssoCreateTime,
				   String ssoUpdateById,
				   String ssoUpdateByName,
				   LocalDateTime ssoUpdateTime,
				   String remarks) {
		super(username, password, enabled, accountNonExpired, credentialsNonExpired, accountNonLocked, authorities);
		this.id = id;
		this.nickName = nickName;
		this.email = email;
		this.phone = phone;
		this.sex = sex;
		this.avatar = avatar;
		this.loginIp = loginIp;
		this.loginTime = loginTime;
		this.ssoStatus = ssoStatus;
		this.ssoCreateById = ssoCreateById;
		this.ssoCreateByName = ssoCreateByName;
		this.ssoCreateTime = ssoCreateTime;
		this.ssoUpdateById = ssoUpdateById;
		this.ssoUpdateByName = ssoUpdateByName;
		this.ssoUpdateTime = ssoUpdateTime;
		this.remarks = remarks;
	}

	public CasUser(String username,
				   String password,
				   boolean enabled,
				   boolean accountNonExpired,
				   boolean credentialsNonExpired,
				   boolean accountNonLocked,
				   Collection<? extends GrantedAuthority> authorities,
				   String id,
				   String nickName,
				   String email,
				   String phone,
				   String sex,
				   String avatar,
				   String loginIp,
				   LocalDateTime loginTime,
				   String ssoStatus,
				   String ssoCreateById,
				   String ssoCreateByName,
				   LocalDateTime ssoCreateTime,
				   String ssoUpdateById,
				   String ssoUpdateByName,
				   LocalDateTime ssoUpdateTime,
				   String remarks,
				   String roleId,
				   String tenantId) {
		super(username, password, enabled, accountNonExpired, credentialsNonExpired, accountNonLocked, authorities);
		this.id = id;
		this.nickName = nickName;
		this.email = email;
		this.phone = phone;
		this.sex = sex;
		this.avatar = avatar;
		this.loginIp = loginIp;
		this.loginTime = loginTime;
		this.ssoStatus = ssoStatus;
		this.ssoCreateById = ssoCreateById;
		this.ssoCreateByName = ssoCreateByName;
		this.ssoCreateTime = ssoCreateTime;
		this.ssoUpdateById = ssoUpdateById;
		this.ssoUpdateByName = ssoUpdateByName;
		this.ssoUpdateTime = ssoUpdateTime;
		this.remarks = remarks;
		this.roleId = roleId;
		this.tenantId = tenantId;
	}

}
