package com.klab.security.common.config;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.klab.security.common.exp.*;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.security.oauth2.provider.token.ResourceServerTokenServices;
import org.springframework.security.oauth2.provider.token.TokenStore;

/**
 *<p>
 * 扩展资源服务器自动配置
 *</p>
 *
 * @Author: wangxiang4
 * @Since: 2023/8/24
 */
@Configuration
@EnableConfigurationProperties(PermitAllUrlProperties.class)
public class ResourceServerAutoConfiguration {

	/** 校验接口是否存在权限 */
	@Bean("pms")
	public PermissionService permissionService() {
		return new PermissionService();
	}

	/** 对公开权限的请求获取token不进行校验 */
	@Bean
	public KiccBearerTokenExtractor kiccBearerTokenExtractor(PermitAllUrlProperties urlProperties) {
		return new KiccBearerTokenExtractor(urlProperties);
	}

	/** 细粒化客户端认证异常处理 */
	@Bean
	public ResourceAuthExceptionEntryPoint resourceAuthExceptionEntryPoint(ObjectMapper objectMapper) {
		return new ResourceAuthExceptionEntryPoint(objectMapper);
	}

	/** 扩展资源服务器令牌服务 */
	@Bean
	@Primary
	public ResourceServerTokenServices resourceServerTokenServices(TokenStore tokenStore, JdbcTemplate jdbcTemplate) {
		return new KiccLocalResourceServerTokenServices(tokenStore, jdbcTemplate);
	}

}
