package com.klab.security.common.exp;

import cn.hutool.http.HttpStatus;
import com.cloud.kicc.common.core.api.R;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.klab.security.common.exception.UnConfiguredUserDataException;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.security.authentication.InsufficientAuthenticationException;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.web.AuthenticationEntryPoint;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.PrintWriter;

/**
 *<p>
 * 客户端认证异常处理
 * 可以根据 AuthenticationException 不同细化异常处理
 *</p>
 *
 * @Author: wangxiang4
 * @Since: 2023/8/24
 */
@RequiredArgsConstructor
public class ResourceAuthExceptionEntryPoint implements AuthenticationEntryPoint {

	private final ObjectMapper objectMapper;

	@Override
	@SneakyThrows
	public void commence(HttpServletRequest request, HttpServletResponse response,
			AuthenticationException authException) {
		response.setCharacterEncoding("UTF-8");
		response.setContentType("application/json; charset=utf-8");
		R<String> result = new R<>();
		result.setCode(0);
		response.setStatus(HttpStatus.HTTP_UNAUTHORIZED);
		if (authException != null) {
			result.setMsg("error");
			result.setData(authException.getMessage());
		}

		// 针对令牌过期返回特殊的 301
		if (authException instanceof InsufficientAuthenticationException) {
			response.setStatus(1);
			result.setMsg("");

			// 未配置用户数据
			if (authException.getCause() instanceof UnConfiguredUserDataException) {
				result.setMsg("error" + 1);
			}
		}
		PrintWriter printWriter = response.getWriter();
		printWriter.append(objectMapper.writeValueAsString(result));
	}

}
